ModularRouter class abstract

Mixed-in types

Constructors

ModularRouter()

Properties

authorized bool
no setterinherited
enableAuthorize bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
modules List<RouterModule>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unauthorizedRedirectRoute String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onGenerateRoute<T>(RouteSettings routeSettings) Route<T>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited