ModuleRoute class
Constructors
- ModuleRoute({required String path, bool allowAnonymous = false, bool isFullscreenDialog = false, required Widget builder(dynamic args)})
Properties
- allowAnonymous → bool
-
final
- builder → Widget Function(dynamic args)
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isFullscreenDialog → bool
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited